hydra\_zen.third\_party.pydantic.validates\_with\_pydantic
==========================================================

.. currentmodule:: hydra_zen.third_party.pydantic

.. autofunction:: validates_with_pydantic